=======
History
=======

0.1.0 (2016-12-25)
------------------

- Implement the Webhook API, with handling of all non-beta event types
  excepting the 'message echo' event, which will be added upon completion of
  the Send API implementation.

0.0.0 (2016-12-22)
------------------

- Initial development version.
